@@ -1,6 +1,6 @@
 /**
- * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or http://ckeditor.com/license
+ * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 CKEDITOR.plugins.setLang( 'a11yhelp', 'fa', {
@@ -79,29 +79,26 @@ CKEDITOR.plugins.setLang( 'a11yhelp', 'fa', {
 			{
 			name: 'راهنمای دسترسی',
 			legend: 'فشردن ${a11yHelp}'
+		},
+			{
+			name: ' Paste as plain text', // MISSING
+			legend: 'Press ${pastetext}', // MISSING
+			legendEdge: 'Press ${pastetext}, followed by ${paste}' // MISSING
 		}
 		]
 	}
 	],
-	backspace: 'عقبگرد',
 	tab: 'برگه',
-	enter: 'ورود',
-	shift: 'تعویض',
-	ctrl: 'کنترل',
-	alt: 'دگرساز',
 	pause: 'توقف',
 	capslock: 'Caps Lock',
 	escape: 'گریز',
 	pageUp: 'صفحه به بالا',
 	pageDown: 'صفحه به پایین',
-	end: 'پایان',
-	home: 'خانه',
 	leftArrow: 'پیکان چپ',
 	upArrow: 'پیکان بالا',
 	rightArrow: 'پیکان راست',
 	downArrow: 'پیکان پایین',
 	insert: 'ورود',
-	'delete': 'حذف',
 	leftWindowKey: 'کلید چپ ویندوز',
 	rightWindowKey: 'کلید راست ویندوز',
 	selectKey: 'انتخاب کلید',
