@@ -1,6 +1,6 @@
 ﻿/**
- * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or http://ckeditor.com/license
+ * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 'use strict';
@@ -10,7 +10,7 @@
 
 	CKEDITOR.plugins.add( 'autoembed', {
 		requires: 'autolink,undo',
-		lang: 'cs,de,de-ch,en,eo,eu,fr,it,ko,ku,mk,nb,pl,pt-br,ru,tr,ug,uk,zh,zh-cn', // %REMOVE_LINE_CORE%
+		lang: 'az,ca,cs,da,de,de-ch,el,en,en-au,eo,es,es-mx,eu,fr,gl,hr,hu,it,ja,km,ko,ku,mk,nb,nl,oc,pl,pt,pt-br,ro,ru,sk,sq,sv,tr,ug,uk,vi,zh,zh-cn', // %REMOVE_LINE_CORE%
 		init: function( editor ) {
 			var currentId = 1,
 				embedCandidatePasted;
@@ -36,7 +36,7 @@
 				// If one pasted an embeddable link and then undone the action, the link in the content holds the
 				// data-cke-autoembed attribute and may be embedded on *any* successive paste.
 				// This check ensures that autoEmbedLink is called only if afterPaste is fired *right after*
-				// embeddable link got into the content. (#13532)
+				// embeddable link got into the content. (https://dev.ckeditor.com/ticket/13532)
 				if ( embedCandidatePasted ) {
 					autoEmbedLink( editor, currentId );
 				}
@@ -61,7 +61,7 @@
 			return;
 		}
 
-			// TODO Move this to a method in the widget plugin. #13408
+			// TODO Move this to a method in the widget plugin. https://dev.ckeditor.com/ticket/13408
 		var defaults = typeof widgetDef.defaults == 'function' ? widgetDef.defaults() : widgetDef.defaults,
 			element = CKEDITOR.dom.element.createFromHtml( widgetDef.template.output( defaults ) ),
 			instance,
@@ -94,10 +94,10 @@
 					editor.fire( 'saveSnapshot' );
 
 					// Lock snapshot so we don't make unnecessary undo steps in
-					// editable.insertElement() below, which would include bookmarks. (#13429)
+					// editable.insertElement() below, which would include bookmarks. (https://dev.ckeditor.com/ticket/13429)
 					editor.fire( 'lockSnapshot', { dontUpdate: true } );
 
-					// Bookmark current selection. (#13429)
+					// Bookmark current selection. (https://dev.ckeditor.com/ticket/13429)
 					var bookmark = selection.createBookmarks( false )[ 0 ],
 						startNode = bookmark.startNode,
 						endNode = bookmark.endNode || startNode;
@@ -118,7 +118,7 @@
 					editable.insertElement( wrapper, insertRange );
 
 					// If both bookmarks are still in DOM, it means that selection was not inside
-					// an anchor that got substituted. We can safely recreate that selection. (#13429)
+					// an anchor that got substituted. We can safely recreate that selection. (https://dev.ckeditor.com/ticket/13429)
 					if ( editable.contains( startNode ) && editable.contains( endNode ) ) {
 						selection.selectBookmarks( [ bookmark ] );
 					} else {
@@ -181,8 +181,8 @@
 
 	/**
 	 * Specifies the widget to use to automatically embed a link. The default value
-	 * of this option defines that either the [Media Embed](ckeditor.com/addon/embed) or
-	 * [Semantic Media Embed](ckeditor.com/addon/embedsemantic) widgets will be used, depending on which is enabled.
+	 * of this option defines that either the [Media Embed](https://ckeditor.com/cke4/addon/embed) or
+	 * [Semantic Media Embed](https://ckeditor.com/cke4/addon/embedsemantic) widgets will be used, depending on which is enabled.
 	 *
 	 * The general behavior:
 	 *
@@ -194,18 +194,22 @@
 	 *
 	 * Example:
 	 *
-	 *		// Defines that embedSemantic should be used (regardless of whether embed is defined).
-	 *		config.autoEmbed_widget = 'embedSemantic';
+	 * ```js
+	 * // Defines that embedSemantic should be used (regardless of whether embed is defined).
+	 * config.autoEmbed_widget = 'embedSemantic';
+	 * ```
 	 *
 	 * Using with custom embed widgets:
 	 *
-	 *		config.autoEmbed_widget = 'customEmbed';
+	 * ```js
+	 * config.autoEmbed_widget = 'customEmbed';
+	 * ```
 	 *
 	 * **Note:** Plugin names are always lower case, while widget names are not, so widget names do not have to equal plugin names.
 	 * For example, there is the `embedsemantic` plugin and the `embedSemantic` widget.
 	 *
 	 * Read more in the [documentation](#!/guide/dev_media_embed-section-automatic-embedding-on-paste)
-	 * and see the [SDK sample](http://sdk.ckeditor.com/samples/mediaembed.html).
+	 * and see the [SDK sample](https://sdk.ckeditor.com/samples/mediaembed.html).
 	 *
 	 * @since 4.5
 	 * @cfg {String/Function} [autoEmbed_widget='embed,embedSemantic']
