@@ -1,13 +1,13 @@
 /**
- * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or http://ckeditor.com/license
+ * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 ( function() {
 	'use strict';
 
 	// Regex by Imme Emosol.
-	var validUrlRegex = /^(https?|ftp):\/\/(-\.)?([^\s\/?\.#-]+\.?)+(\/[^\s]*)?[^\s\.,]$/ig,
+	var validUrlRegex = /^(https?|ftp):\/\/(-\.)?([^\s\/?\.#]+\.?)+(\/[^\s]*)?[^\s\.,]$/ig,
 		doubleQuoteRegex = /"/g;
 
 	CKEDITOR.plugins.add( 'autolink', {
@@ -26,7 +26,7 @@
 					return;
 				}
 
-				// #13419
+				// https://dev.ckeditor.com/ticket/13419
 				data = data.replace( validUrlRegex , '<a href="' + data.replace( doubleQuoteRegex, '%22' ) + '">$&</a>' );
 
 				// If link was discovered, change the type to 'html'. This is important e.g. when pasting plain text in Chrome
@@ -39,4 +39,4 @@
 			} );
 		}
 	} );
-} )();
\ No newline at end of file
+} )();
