@@ -1,14 +1,87 @@
 ﻿/**
- * @license Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or http://ckeditor.com/license
+ * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 ( function() {
 	'use strict';
 
+	/**
+	 * JSONP communication.
+	 *
+	 * @private
+	 * @singleton
+	 * @class CKEDITOR.plugins.embedBase._jsonp
+	 */
+	var Jsonp = {
+		/**
+		 * Creates a `<script>` element and attaches it to the document `<body>`.
+		 *
+		 * @private
+		 */
+		_attachScript: function( url, errorCallback ) {
+			// ATM we cannot use CKE scriptloader here, because it will make sure that script
+			// with given URL is added only once.
+			var script = new CKEDITOR.dom.element( 'script' );
+			script.setAttribute( 'src', url );
+			script.on( 'error', errorCallback );
+
+			CKEDITOR.document.getBody().append( script );
+
+			return script;
+		},
+
+		/**
+		 * Sends a request using the JSONP technique.
+		 *
+		 * @param {CKEDITOR.template} urlTemplate The template of the URL to be requested. All properties
+		 * passed in `urlParams` can be used, plus a `{callback}`, which represents a JSONP callback, must be defined.
+		 * @param {Object} urlParams Parameters to be passed to the `urlTemplate`.
+		 * @param {Function} callback
+		 * @param {Function} [errorCallback]
+		 * @returns {Object} The request object with a `cancel()` method.
+		 */
+		sendRequest: function( urlTemplate, urlParams, callback, errorCallback ) {
+			var request = {};
+			urlParams = urlParams || {};
+
+			var callbackKey = CKEDITOR.tools.getNextNumber(),
+				scriptElement;
+
+			urlParams.callback = 'CKEDITOR._.jsonpCallbacks[' + callbackKey + ']';
+
+			CKEDITOR._.jsonpCallbacks[ callbackKey ] = function( response ) {
+				// On IEs scripts are sometimes loaded synchronously. It is bad for two reasons:
+				// * nature of sendRequest() is unstable,
+				// * scriptElement does not exist yet.
+				setTimeout( function() {
+					cleanUp();
+					callback( response );
+				} );
+			};
+
+			scriptElement = this._attachScript( urlTemplate.output( urlParams ), function() {
+				cleanUp();
+				errorCallback && errorCallback();
+			} );
+
+			request.cancel = cleanUp;
+
+			function cleanUp() {
+				if ( scriptElement ) {
+					scriptElement.remove();
+					delete CKEDITOR._.jsonpCallbacks[ callbackKey ];
+					scriptElement = null;
+				}
+			}
+
+			return request;
+		}
+	};
+
 	CKEDITOR.plugins.add( 'embedbase', {
-		lang: 'cs,da,de,de-ch,en,eo,eu,fr,gl,id,it,ko,ku,nb,nl,pl,pt-br,ru,sv,tr,ug,uk,zh,zh-cn', // %REMOVE_LINE_CORE%
-		requires: 'widget,notificationaggregator',
+		lang: 'az,ca,cs,da,de,de-ch,en,en-au,eo,es,es-mx,eu,fr,gl,hr,hu,id,it,ja,ko,ku,nb,nl,oc,pl,pt,pt-br,ro,ru,sk,sq,sv,tr,ug,uk,zh,zh-cn', // %REMOVE_LINE_CORE%
+		requires: 'dialog,widget,notificationaggregator',
 
 		onLoad: function() {
 			CKEDITOR._.jsonpCallbacks = {};
@@ -394,6 +467,10 @@
 					return '<img src="' + CKEDITOR.tools.htmlEncodeAttr( response.url ) + '" ' +
 						'alt="' + CKEDITOR.tools.htmlEncodeAttr( response.title || '' ) + '" style="max-width:100%;height:auto" />';
 				} else if ( response.type == 'video' || response.type == 'rich' ) {
+					// Embedded iframes are added to page's focus list. Adding negative tabindex attribute
+					// removes their ability to be focused by user. (https://dev.ckeditor.com/ticket/14538)
+					response.html = response.html.replace( /<iframe/g, '<iframe tabindex="-1"' );
+
 					return response.html;
 				}
 
@@ -521,79 +598,6 @@
 		 */
 	}
 
-	/**
-	 * JSONP communication.
-	 *
-	 * @private
-	 * @singleton
-	 * @class CKEDITOR.plugins.embedBase._jsonp
-	 */
-	var Jsonp = {
-		/**
-		 * Creates a `<script>` element and attaches it to the document `<body>`.
-		 *
-		 * @private
-		 */
-		_attachScript: function( url, errorCallback ) {
-			// ATM we cannot use CKE scriptloader here, because it will make sure that script
-			// with given URL is added only once.
-			var script = new CKEDITOR.dom.element( 'script' );
-			script.setAttribute( 'src', url );
-			script.on( 'error', errorCallback );
-
-			CKEDITOR.document.getBody().append( script );
-
-			return script;
-		},
-
-		/**
-		 * Sends a request using the JSONP technique.
-		 *
-		 * @param {CKEDITOR.template} urlTemplate The template of the URL to be requested. All properties
-		 * passed in `urlParams` can be used, plus a `{callback}`, which represent a JSONP callback, must be defined.
-		 * @param {Object} urlParams Parameters to be passed to the `urlTemplate`.
-		 * @param {Function} callback
-		 * @param {Function} [errorCallback]
-		 * @returns {Object} The request object with a `cancel()` method.
-		 */
-		sendRequest: function( urlTemplate, urlParams, callback, errorCallback ) {
-			var request = {};
-			urlParams = urlParams || {};
-
-			var callbackKey = CKEDITOR.tools.getNextNumber(),
-				scriptElement;
-
-			urlParams.callback = 'CKEDITOR._.jsonpCallbacks[' + callbackKey + ']';
-
-			CKEDITOR._.jsonpCallbacks[ callbackKey ] = function( response ) {
-				// On IEs scripts are sometimes loaded synchronously. It is bad for two reasons:
-				// * nature of sendRequest() is unstable,
-				// * scriptElement does not exist yet.
-				setTimeout( function() {
-					cleanUp();
-					callback( response );
-				} );
-			};
-
-			scriptElement = this._attachScript( urlTemplate.output( urlParams ), function() {
-				cleanUp();
-				errorCallback && errorCallback();
-			} );
-
-			request.cancel = cleanUp;
-
-			function cleanUp() {
-				if ( scriptElement ) {
-					scriptElement.remove();
-					delete CKEDITOR._.jsonpCallbacks[ callbackKey ];
-					scriptElement = null;
-				}
-			}
-
-			return request;
-		}
-	};
-
 	/**
 	 * Class representing the request object. It is created by the {@link CKEDITOR.plugins.embedBase.baseDefinition#loadContent}
 	 * method and is passed to other methods and events of this class.
