@@ -1,6 +1,6 @@
 /*
-Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'image2', 'he', {
 	alt: 'טקסט חלופי',
@@ -16,5 +16,6 @@ CKEDITOR.plugins.setLang( 'image2', 'he', {
 	resizer: 'לחץ וגרור לשינוי הגודל',
 	title: 'מאפייני התמונה',
 	uploadTab: 'העלאה',
-	urlMissing: 'כתובת התמונה חסרה.'
+	urlMissing: 'כתובת התמונה חסרה.',
+	altMissing: 'Alternative text is missing.' // MISSING
 } );
