@@ -1,6 +1,6 @@
 /*
-Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'liststyle', 'fr', {
 	armenian: 'Numération arménienne',
@@ -10,16 +10,16 @@ CKEDITOR.plugins.setLang( 'liststyle', 'fr', {
 	decimalLeadingZero: 'Décimal précédé par un 0 (01, 02, 03, etc.)',
 	disc: 'Disque',
 	georgian: 'Numération géorgienne (an, ban, gan, etc.)',
-	lowerAlpha: 'Alphabétique minuscules (a, b, c, d, e, etc.)',
-	lowerGreek: 'Grec minuscule (alpha, beta, gamma, etc.)',
-	lowerRoman: 'Nombres romains minuscules (i, ii, iii, iv, v, etc.)',
+	lowerAlpha: 'Lettres minuscules (a, b, c, d, e, etc.)',
+	lowerGreek: 'Grec minuscule (alpha, bêta, gamma, etc.)',
+	lowerRoman: 'Chiffres romains minuscules (i, ii, iii, iv, v, etc.)',
 	none: 'Aucun',
-	notset: '<Non défini>',
+	notset: '<indéfini>',
 	numberedTitle: 'Propriétés de la liste numérotée',
 	square: 'Carré',
 	start: 'Début',
 	type: 'Type',
-	upperAlpha: 'Alphabétique majuscules (A, B, C, D, E, etc.)',
-	upperRoman: 'Nombres romains majuscules (I, II, III, IV, V, etc.)',
+	upperAlpha: 'Lettres majuscules (A, B, C, D, E, etc.)',
+	upperRoman: 'Chiffres romains majuscules (I, II, III, IV, V, etc.)',
 	validateStartNumber: 'Le premier élément de la liste doit être un nombre entier.'
 } );
