@@ -1,4 +1,4 @@
-/* bender-tags: editor,unit,dom,range */
+/* bender-tags: editor,dom,range */
 
 ( function() {
 	'use strict';
@@ -194,7 +194,7 @@
 			assert.isTrue( doc.getById( '_enclosed_i' ).equals( range.getEnclosedNode() ) );
 		},
 
-		/* Start of #6735 */
+		/* Start of https://dev.ckeditor.com/ticket/6735 */
 
 		'test checkReadOnly when both range boundaries are inside of read-only element': function() {
 			var source = 'some <strong contenteditable="false"> sample [text</strong> and a <a href="javascript:void(0)" contenteditable="false">link]</a>',
@@ -220,7 +220,7 @@
 			assert.isFalse( range.checkReadOnly() );
 		},
 
-		/* End of #6735 */
+		/* End of https://dev.ckeditor.com/ticket/6735 */
 
 		'test checkReadOnly when entire range is enclosed in an editable element which is contained by another read-only element': function() {
 			var source = 'some <strong contenteditable="false"> sample text and <a href="javascript:void(0)" contenteditable="true">a [link].</a></strong>',
@@ -288,8 +288,122 @@
 
 			range._setEndContainer( end );
 			assert.areSame( end, range.endContainer );
+		},
+
+		'test _getTableElement': function() {
+			var range = new CKEDITOR.dom.range( doc );
+
+			// Collapsed range inside td.
+			range.setStart( doc.getById( '_td1' ).getFirst(), 1 );
+			range.collapse();
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_td1' ) ), 'collapsed td' );
+
+			// Collapsed range inside th.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStart( doc.getById( '_th1' ).getFirst(), 1 );
+			range.collapse();
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_th1' ) ), 'collapsed th' );
+
+			// Normal range inside td.
+			range = new CKEDITOR.dom.range( doc );
+			range.selectNodeContents( doc.getById( '_td1' ).getFirst() );
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_td1' ) ), 'inside td' );
+
+			// Partial range inside td.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStart( doc.getById( '_td1' ).getFirst(), 1 );
+			range.setEnd( doc.getById( '_td1' ).getFirst(), 3 );
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_td1' ) ), 'partial inside td' );
+
+			// Selected cell.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_td1' ) );
+			range.setEndAfter( doc.getById( '_td1' ) );
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_td1' ) ), 'selected td' );
+
+			// Selected heading.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_th1' ) );
+			range.setEndAfter( doc.getById( '_th1' ) );
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_th1' ) ), 'selected th' );
+
+			// Selected thead.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_thead' ) );
+			range.setEndAfter( doc.getById( '_thead' ) );
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_thead' ) ), 'selected thead' );
+
+			// Selected tbody.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_tbody' ) );
+			range.setEndAfter( doc.getById( '_tbody' ) );
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_tbody' ) ), 'selected tbody' );
+
+			// Selected tfoot.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_tfoot' ) );
+			range.setEndAfter( doc.getById( '_tfoot' ) );
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_tfoot' ) ), 'selected tfoot' );
+
+			// Selected table.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_table1' ) );
+			range.setEndAfter( doc.getById( '_table1' ) );
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_table1' ) ), 'selected table1' );
+
+			// Selected two cells.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_td1' ) );
+			range.setEndAfter( doc.getById( '_td2' ) );
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_tr2' ) ), 'selected 2 tds' );
+
+			// Selected two cells from different tables.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_td2' ) );
+			range.setEndAfter( doc.getById( '_td3' ) );
+
+			assert.isNull( range._getTableElement(), 'selected 2 tds from different tables' );
+
+			// Selected two tables.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_table1' ) );
+			range.setEndAfter( doc.getById( '_table2' ) );
+
+			assert.isNull( range._getTableElement(), 'selected 2 tables' );
+
+			// Selected paragraph.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_P' ) );
+			range.setEndAfter( doc.getById( '_P' ) );
+
+			assert.isNull( range._getTableElement(), 'selected paragraph' );
+
+			// Special case in Safari: selecting cell inside one-cell table.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_td3' ) );
+			range.setEndAfter( doc.getById( '_td3' ) );
+
+			assert.isTrue( range._getTableElement().equals( doc.getById( '_td3' ) ), 'selected td in one-cell table' );
+
+			// Filtering returned elements.
+			range = new CKEDITOR.dom.range( doc );
+			range.setStartBefore( doc.getById( '_td1' ) );
+			range.setEndAfter( doc.getById( '_td1' ) );
+
+			assert.isTrue( range._getTableElement( 'tbody' ).equals( doc.getById( '_tbody' ) ), 'filtering elements' );
 		}
 	};
 
 	bender.test( tests );
-} )();
\ No newline at end of file
+} )();
