@@ -1,11 +1,12 @@
-/* bender-tags: editor,unit */
+/* bender-tags: editor */
 /* bender-ckeditor-plugins: basicstyles,undo,sourcearea,toolbar */
 
 bender.editor = {
 	config: {
 		extraAllowedContent: 'p span em ul li[id,contenteditable]',
 		// They make HTML comparison different in build and dev modes.
-		removePlugins: 'htmlwriter,entities'
+		removePlugins: 'htmlwriter,entities',
+		extraPlugins: 'placeholder'
 	}
 };
 
@@ -74,6 +75,10 @@ function getKeyEvent( keyCode, preventDefaultCallback ) {
 }
 
 bender.test( {
+	tearDown: function() {
+		this.editor.setReadOnly( false );
+	},
+
 	'Make fake-selection': function() {
 		var editor = this.editor;
 
@@ -107,9 +112,15 @@ bender.test( {
 	},
 
 	'Reset fake-selection': function() {
-		var editor = this.editor;
+		var editor = this.editor,
+			inputHtml = '<p>{foo <span id="bar">bar</span>}</p>';
 
-		bender.tools.setHtmlWithSelection( editor, '<p>[foo <span id="bar">bar</span>]</p>' );
+		// Edge behaves very weird if there's element selection inside paragraph in this test.
+		if ( !CKEDITOR.env.edge || CKEDITOR.env.version < 14 ) {
+			inputHtml = '<p>[foo <span id="bar">bar</span>]</p>';
+		}
+
+		bender.tools.setHtmlWithSelection( editor, inputHtml );
 
 		var span = editor.document.getById( 'bar' ),
 			sel = editor.getSelection();
@@ -199,6 +210,15 @@ bender.test( {
 		assert.isFalse( !!countHiddenContainers( editor.document ), 'There sould be no hidden selection container' );
 	},
 
+	'Hiding selection encodes label': function() {
+		var editor = this.editor;
+
+		bender.tools.setHtmlWithSelection( editor, '<p>[<span id="bar">bar</span>]</p>' );
+
+		editor.getSelection().fake( editor.document.getById( 'bar' ), '<i>foo</i>' );
+		assert.areEqual( '&lt;i&gt;foo&lt;/i&gt;', editor.editable().findOne( 'div[data-cke-hidden-sel]' ).getHtml() );
+	},
+
 	'Clean up on setData in framed editor': function() {
 		var editor = this.editor;
 
@@ -266,7 +286,7 @@ bender.test( {
 		assert.isTrue( editor.getSelection( 1 ).isHidden(), 'Real selection is placed in hidden element' );
 	},
 
-	'Fake-selection bookmark mark as not faked when no enclosed node found. (#13280)': function() {
+	'Fake-selection bookmark mark as not faked when no enclosed node found. (https://dev.ckeditor.com/ticket/13280)': function() {
 		bender.tools.selection.setWithHtml( this.editor, '<p>fo{o ba}r</p>' );
 
 		var sel = this.editor.getSelection(),
@@ -1017,7 +1037,7 @@ bender.test( {
 		} );
 	},
 
-	// #11393.
+	// https://dev.ckeditor.com/ticket/11393.
 	'Test select editable contents when fake selection was on and DOM has been overwritten': function() {
 		var editor = this.editor;
 
@@ -1048,5 +1068,33 @@ bender.test( {
 			// Be sure the selection is really there - regexp doesn't check it.
 			assert.isTrue( !!html.match( /\[/ ) && !!html.match( /\]/ ), 'Selection exists' );
 		} );
+	},
+
+	// #1516
+	'Test delete/backspace keys are not removing readonly selection': function() {
+
+		// Test has been ignored for IE due to #1575 issue. Remove this ignore statement after the issue fix.
+		if ( CKEDITOR.env.ie && !CKEDITOR.env.edge ) {
+			assert.ignore();
+		}
+
+		var editor = this.editor, bot = this.editorBot;
+
+		editor.setReadOnly( true );
+
+		bot.setData( '<p>[[placeholder]]</p>', function() {
+			var widget = editor.widgets.instances[ 0 ],
+				domEvent = {
+					getKey: function() {
+						return false;
+					}
+				};
+			widget.focus();
+
+			editor.fire( 'key', { keyCode: 8, domEvent: domEvent } ); // backspace
+			editor.fire( 'key', { keyCode: 46, domEvent: domEvent } ); // delete
+
+			assert.areEqual( '<p>[[placeholder]]</p>', editor.getData() );
+		} );
 	}
 } );
