@@ -1,4 +1,4 @@
-/* bender-tags: editor,unit,widget */
+/* bender-tags: editor,widget */
 /* bender-ckeditor-plugins: image2,toolbar */
 /* global widgetTestsTools */
 
@@ -64,7 +64,7 @@
 			} );
 		},
 
-		// #11283
+		// https://dev.ckeditor.com/ticket/11283
 		'test upcast: ENTER_P, non-captioned, centered->DIV{text-align}': function() {
 			assertUpcast( {
 				name: 'enterP',
@@ -80,7 +80,7 @@
 			} );
 		},
 
-		// #11283
+		// https://dev.ckeditor.com/ticket/11283
 		'test upcast: ENTER_BR, non-captioned, centered->DIV{text-align}': function() {
 			assertUpcast( {
 				name: 'enterBR',
@@ -96,7 +96,7 @@
 			} );
 		},
 
-		// #11283
+		// https://dev.ckeditor.com/ticket/11283
 		'test upcast: ENTER_BR, non-captioned, centered->DIV{text-align}, siblings': function() {
 			assertUpcast( {
 				name: 'enterBR',
@@ -111,6 +111,25 @@
 				assert.areSame( 1, instances.length, 'A single widget has been initialized' );
 				assert.areSame( 'none', widget.data.align, 'Centering with DIV not possible if has siblings' );
 			} );
+		},
+
+		// https://dev.ckeditor.com/ticket/14701
+		'test upcast: setting proper label': function() {
+			assertUpcast( {
+				name: 'enterP',
+				data: '<div style="text-align:center">' +
+					'sibling' +
+					'<img id="w1" src="_assets/foo.png" alt="foo" />' +
+				'</div>'
+			}, function( editor ) {
+				var instances = obj2Array( editor.widgets.instances ),
+					widget = instances[ 0 ],
+					expectedLabel = editor.lang.widget.label.replace( /%1/,
+						'foo ' + widget.pathName );
+
+				assert.areSame( expectedLabel, widget.getLabel(), 'getLabel() return value' );
+				assert.areSame( expectedLabel, widget.wrapper.getAttribute( 'aria-label' ), 'widget aria-label value' );
+			} );
 		}
 	} );
-} )();
\ No newline at end of file
+} )();
