@@ -198,7 +198,7 @@ var widgetTestsTools = ( function() {
 	// @param {Number} offset 0-based widget offset.
 	// @returns {CKEDITOR.plugins.widget/null} Returns null if widget was not found.
 	function getWidgetByDOMOffset( editor, offset ) {
-		var wrapper = editor.document.find( '.cke_widget_wrapper' ).getItem( offset ),
+		var wrapper = editor.editable().find( '.cke_widget_wrapper' ).getItem( offset ),
 			ret = null;
 
 		if ( wrapper )
@@ -373,16 +373,18 @@ var widgetTestsTools = ( function() {
 		assertWidget: assertWidget,
 
 		widgetInitedWrapperAttributes:
-			'class="cke_widget_wrapper cke_widget_(?:inline|block)" ' +
+			'aria-label="[a-z]+ widget" ' +
+			'class="cke_widget_wrapper cke_widget_(?:inline|block) cke_widget_test(?:_upcasted_pasting|inline|block)" ' +
 			'contenteditable="false" ' +
 			'(?:data-cke-display-name="[a-z0-9]+" )?' +
 			'(?:data-cke-expando="[0-9]+" )?' +
 			'data-cke-filter="off" ' +
 			'data-cke-widget-id="[0-9]+" ' +
 			'data-cke-widget-wrapper="1" ' +
+			'role="region" ' +
 			'tabindex="-1"',
 		widgetWrapperAttributes:
-			'class="cke_widget_wrapper cke_widget_new cke_widget_(?:inline|block)" ' +
+			'class="cke_widget_wrapper cke_widget_new cke_widget_(?:inline|block) cke_widget_test(?:1|2|inline|block)?" ' +
 			'contenteditable="false" ' +
 			'(?:data-cke-display-name="[a-z0-9]+" )?' +
 			'(?:data-cke-expando="[0-9]+" )?' +
@@ -396,6 +398,7 @@ var widgetTestsTools = ( function() {
 					'data-cke-widget-drag-handler="1" ' +
 					'(?:draggable="true" )?' +
 					'height="\\d+" ' +
+					'role="presentation" ' +
 					'src="[^"]+" ' +
 					'title="[^"]+" ' +
 					'width="\\d+" ' +
@@ -403,4 +406,4 @@ var widgetTestsTools = ( function() {
 			'</span>'
 	};
 
-} )();
\ No newline at end of file
+} )();
