@@ -11,6 +11,7 @@
 	var editorConfig = {
 		plugins: 'wysiwygarea,sourcearea,widget,clipboard',
 		allowedContent: true,
+		language: 'en',
 		on: {
 			pluginsLoaded: function( evt ) {
 				evt.editor.dataProcessor.writer.sortAttributes = 1;
@@ -52,6 +53,10 @@
 	}
 
 	bender.test( {
+		tearDown: function() {
+			this.editor.setReadOnly( false );
+		},
+
 		'test initializing widgets': function() {
 			var editor = this.editor;
 
@@ -634,6 +639,44 @@
 			} );
 		},
 
+		// #1570
+		'test cutting single focused widget with readonly mode': function() {
+			// Test has been ignored for IE due to #1632 issue. Remove this ignore statement after the issue fix.
+			if ( CKEDITOR.env.ie ) {
+				assert.ignore();
+			}
+
+			var editor = this.editor;
+
+			this.editorBot.setData( '<p>X</p><p id="w1" data-widget="test2">A</p><p>X</p>', function() {
+				var widget = getWidgetById( editor, 'w1' ),
+					selectionChanged = 0;
+
+				widget.focus();
+
+				editor.on( 'selectionChange', function() {
+					selectionChanged += 1;
+				} );
+
+				editor.setReadOnly( true );
+
+				editor.editable().fire( 'keydown', new CKEDITOR.dom.event( { keyCode: CKEDITOR.CTRL + 88 } ) );
+
+				var copybin = editor.document.getById( 'cke_copybin' ),
+					selContainer = editor.getSelection().getCommonAncestor();
+
+				assert.isTrue( !!copybin, 'copybin was created' );
+				assert.isTrue( copybin.contains( selContainer ) || copybin.equals( selContainer ), 'selection was moved to the copybin' );
+
+				wait( function() {
+					assert.isTrue( selectionChanged == 0, 'selection has not been changed' );
+					assert.isTrue( !!getWidgetById( editor, 'w1' ), 'widget has not been deleted' );
+					assert.isFalse( !!editor.getSelection().isFake, 'selection is not faked' );
+					assert.isFalse( !!editor.document.getById( 'cke_copybin' ), 'copybin was removed' );
+				}, 150 );
+			} );
+		},
+
 		'test pasting single focused widget': function() {
 			var editor = this.editor;
 
@@ -668,7 +711,7 @@
 			} );
 		},
 
-		// #13460
+		// https://dev.ckeditor.com/ticket/13460
 		'test pasting a widget with lots of extra markup and mixed HTML case': function() {
 			var editor = this.editor;
 
@@ -998,4 +1041,4 @@
 			} );
 		}
 	} );
-} )();
\ No newline at end of file
+} )();
